[Git][gajim/gajim][master] Fix typo

Philipp Hörist gitlab at dev.gajim.org
Sat Jul 28 13:33:34 CEST 2018


Philipp Hörist pushed to branch master at gajim / gajim


Commits:
7584037f by Philipp Hörist at 2018-07-28T11:32:37Z
Fix typo

- - - - -


6 changed files:

- gajim/common/connection.py
- gajim/common/helpers.py
- gajim/common/modules/delimiter.py
- gajim/common/modules/discovery.py
- gajim/common/modules/metacontacts.py
- gajim/common/modules/roster.py


Changes:

=====================================
gajim/common/connection.py
=====================================
--- a/gajim/common/helpers.py
+++ b/gajim/common/helpers.py
@@ -1512,7 +1512,7 @@ def get_emoticon_theme_path(theme):
 def call_counter(func):
     def helper(self, restart=False):
         if restart:
-            self._connect_maschine_calls = 0
-        self._connect_maschine_calls += 1
+            self._connect_machine_calls = 0
+        self._connect_machine_calls += 1
         return func(self, restart=False)
     return helper


=====================================
gajim/common/modules/delimiter.py
=====================================
--- a/gajim/common/modules/delimiter.py
+++ b/gajim/common/modules/delimiter.py
@@ -51,7 +51,7 @@ class Delimiter:
             else:
                 self.set_roster_delimiter()
 
-        self._con.connect_maschine()
+        self._con.connect_machine()
 
     def set_roster_delimiter(self):
         log.info('Set delimiter')


=====================================
gajim/common/modules/discovery.py
=====================================
--- a/gajim/common/modules/discovery.py
+++ b/gajim/common/modules/discovery.py
@@ -199,7 +199,7 @@ class Discovery:
         if nbxmpp.NS_ADDRESS in features:
             self._con.addressing_supported = True
 
-        self._con.connect_maschine()
+        self._con.connect_machine()
 
     def _parse_transports(self, from_, identities, features, data, node):
         for identity in identities:


=====================================
gajim/common/modules/metacontacts.py
=====================================
--- a/gajim/common/modules/metacontacts.py
+++ b/gajim/common/modules/metacontacts.py
@@ -53,7 +53,7 @@ class MetaContacts:
             app.nec.push_incoming_event(NetworkEvent(
                 'metacontacts-received', conn=self._con, meta_list=meta_list))
 
-        self._con.connect_maschine()
+        self._con.connect_machine()
 
     @staticmethod
     def _parse_metacontacts(stanza):


=====================================
gajim/common/modules/roster.py
=====================================
--- a/gajim/common/modules/roster.py
+++ b/gajim/common/modules/roster.py
@@ -104,7 +104,7 @@ class Roster:
                 roster=self._data.copy(),
                 received_from_server=received_from_server))
 
-        self._con.connect_maschine()
+        self._con.connect_machine()
 
     def _roster_push_received(self, con, stanza):
         log.info('Push received')



View it on GitLab: https://dev.gajim.org/gajim/gajim/commit/7584037fc7cbd92daee71d0ea87deb5857b76677

--- a/gajim/common/connection.py
+++ b/gajim/common/connection.py
@@ -123,8 +123,8 @@ class CommonConnection:
 
         self.awaiting_cids = {} # Used for XEP-0231
 
-        # Tracks the calls of the connect_maschine() method
-        self._connect_maschine_calls = 0
+        # Tracks the calls of the connect_machine() method
+        self._connect_machine_calls = 0
 
         self.get_config_values_or_default()
 
@@ -1453,7 +1453,7 @@ class Connection(CommonConnection, ConnectionHandlers):
         # If we are not resuming, we ask for discovery info
         # and archiving preferences
         if not self.sm.supports_sm or (not self.sm.resuming and self.sm.enabled):
             # This starts the connect_maschine
             self.get_module('Discovery').discover_server_info()
             self.get_module('Discovery').discover_account_info()
 
@@ -1470,15 +1470,15 @@ class Connection(CommonConnection, ConnectionHandlers):
             self._stun_servers = self._hosts = [i for i in result_array]
 
     @helpers.call_counter
-    def connect_maschine(self, restart=False):
-        log.info('Connect maschine state: %s', self._connect_maschine_calls)
-        if self._connect_maschine_calls == 1:
+    def connect_machine(self, restart=False):
+        log.info('Connect machine state: %s', self._connect_machine_calls)
+        if self._connect_machine_calls == 1:
             self.get_module('MetaContacts').get_metacontacts()
-        elif self._connect_maschine_calls == 2:
+        elif self._connect_machine_calls == 2:
             self.get_module('Delimiter').get_roster_delimiter()
-        elif self._connect_maschine_calls == 3:
+        elif self._connect_machine_calls == 3:
             self.get_module('Roster').request_roster()
-        elif self._connect_maschine_calls == 4:
+        elif self._connect_machine_calls == 4:
             self.send_first_presence()
 
     def send_custom_status(self, show, msg, jid):
@@ -1453,7 +1453,7 @@ class Connection(CommonConnection, ConnectionHandlers):
         # and archiving preferences
         if not self.sm.supports_sm or (not self.sm.resuming and self.sm.enabled):
-            # This starts the connect_maschine
+            # This starts the connect_machine
             self.get_module('Discovery').discover_server_info()
             self.get_module('Discovery').discover_account_info()


=====================================
gajim/common/helpers.py
=====================================
-- 
View it on GitLab: https://dev.gajim.org/gajim/gajim/commit/7584037fc7cbd92daee71d0ea87deb5857b76677
You're receiving this email because of your account on dev.gajim.org.
-------------- next part --------------
An HTML attachment was scrubbed...
URL: <http://lists.gajim.org/pipermail/commits/attachments/20180728/e68d5f5c/attachment-0001.html>


More information about the Commits mailing list